@@ -56,6 +56,8 @@ GType g_desktop_pad_button_action_get_type (void) G_GNUC_CONST;
 #define G_DESKTOP_TYPE_DESKTOP_PAD_BUTTON_ACTION (g_desktop_pad_button_action_get_type())
 GType g_desktop_stylus_button_action_get_type (void) G_GNUC_CONST;
 #define G_DESKTOP_TYPE_DESKTOP_STYLUS_BUTTON_ACTION (g_desktop_stylus_button_action_get_type())
+GType g_desktop_pointer_accel_profile_get_type (void) G_GNUC_CONST;
+#define G_DESKTOP_TYPE_DESKTOP_POINTER_ACCEL_PROFILE (g_desktop_pointer_accel_profile_get_type())
 /* enumerations from "cc-background-item.h" */
 GType cc_background_item_flags_get_type (void) G_GNUC_CONST;
 #define G_DESKTOP_TYPE_BACKGROUND_ITEM_FLAGS (cc_background_item_flags_get_type())
