@@ -210,7 +210,7 @@ add_address_row (CEPageIP6   *page,
         gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
         g_signal_connect_swapped (widget, "changed", G_CALLBACK (ce_page_changed), page);
         g_object_set_data (G_OBJECT (row), "gateway", widget);
-        gtk_entry_set_text (GTK_ENTRY (widget), gateway);
+        gtk_entry_set_text (GTK_ENTRY (widget), gateway ? gateway : "");
         gtk_widget_set_margin_start (widget, 10);
         gtk_widget_set_margin_end (widget, 10);
         gtk_widget_set_hexpand (widget, TRUE);
@@ -654,10 +654,14 @@ ui_to_setting (CEPageIP6 *page)
         }
 
         nm_setting_ip_config_clear_addresses (page->setting);
-        if (g_str_equal (method, NM_SETTING_IP6_CONFIG_METHOD_MANUAL))
+        if (g_str_equal (method, NM_SETTING_IP6_CONFIG_METHOD_MANUAL)) {
                 children = gtk_container_get_children (GTK_CONTAINER (page->address_list));
-        else
+        } else {
+                g_object_set (G_OBJECT (page->setting),
+                              NM_SETTING_IP_CONFIG_GATEWAY, NULL,
+                              NULL);
                 children = NULL;
+       }
 
         for (l = children; l; l = l->next) {
                 GtkWidget *row = l->data;
@@ -706,6 +710,7 @@ ui_to_setting (CEPageIP6 *page)
                         ret = FALSE;
                 } else {
                         widget_unset_error (g_object_get_data (G_OBJECT (row), "gateway"));
+                        have_gateway = TRUE;
                 }
 
                 if (!ret)
