@@ -29,7 +29,7 @@
 #include "pp-jobs-dialog.h"
 #include "pp-utils.h"
 
-#define SUPPLY_BAR_HEIGHT 12
+#define SUPPLY_BAR_HEIGHT 8
 
 struct _PpPrinterEntry
 {
@@ -164,12 +164,34 @@ typedef struct
   gchar *marker_types;
 } InkLevelData;
 
+/* To tone down the colors in the supply level bar
+ * we shade them by darkening the hue.
+ *
+ * Obs.: we don't know whether the color is already
+ * shaded.
+ *
+ */
+static void
+tone_down_color (GdkRGBA *color,
+                 gdouble  hue_ratio,
+                 gdouble  saturation_ratio,
+                 gdouble  value_ratio)
+{
+  gdouble h, s, v;
+
+  gtk_rgb_to_hsv (color->red, color->green, color->blue,
+                  &h, &s, &v);
+  gtk_hsv_to_rgb (h * hue_ratio, s * saturation_ratio, v * value_ratio,
+                  &color->red, &color->green, &color->blue);
+}
+
 static gboolean
 supply_levels_draw_cb (GtkWidget    *widget,
                        cairo_t      *cr,
                        InkLevelData *inklevel)
 {
   GtkStyleContext        *context;
+  gboolean                is_empty = TRUE;
   gchar                  *tooltip_text = NULL;
   gint                    width;
   gint                    height;
@@ -233,13 +255,22 @@ supply_levels_draw_cb (GtkWidget    *widget,
                 value = ((MarkerItem*) tmp_list->data)->level;
 
                 gdk_rgba_parse (&color, ((MarkerItem*) tmp_list->data)->color);
+                tone_down_color (&color, 1.0, 0.6, 0.9);
 
                 if (value > 0)
                   {
                     display_value = value / 100.0 * (width - 3.0);
                     gdk_cairo_set_source_rgba (cr, &color);
-                    cairo_rectangle (cr, 3.5, 3.5, display_value, SUPPLY_BAR_HEIGHT - 3.0);
+                    cairo_rectangle (cr, 2.0, 2.0, display_value, SUPPLY_BAR_HEIGHT);
                     cairo_fill (cr);
+
+                    tone_down_color (&color, 1.0, 1.0, 0.85);
+                    gdk_cairo_set_source_rgba (cr, &color);
+                    cairo_set_line_width (cr, 1.0);
+                    cairo_rectangle (cr, 1.5, 1.5, display_value, SUPPLY_BAR_HEIGHT + 1);
+                    cairo_stroke (cr);
+
+                    is_empty = FALSE;
                   }
 
                 if (tooltip_text)
@@ -256,7 +287,7 @@ supply_levels_draw_cb (GtkWidget    *widget,
                                                   ((MarkerItem*) tmp_list->data)->name);
               }
 
-            gtk_render_frame (context, cr, 1, 1, width - 1, SUPPLY_BAR_HEIGHT + 3);
+            gtk_render_frame (context, cr, 1, 1, width - 1, SUPPLY_BAR_HEIGHT);
 
             for (tmp_list = markers; tmp_list; tmp_list = tmp_list->next)
               {
@@ -281,6 +312,13 @@ supply_levels_draw_cb (GtkWidget    *widget,
       }
     }
 
+  if (is_empty)
+    {
+      GtkWidget *frame = gtk_widget_get_parent (widget);
+      gtk_style_context_add_class (gtk_widget_get_style_context (frame),
+                                   "background");
+    }
+
   return TRUE;
 }
 
@@ -352,14 +390,14 @@ remove_printer (GtkButton      *button,
   printer_delete (self->printer_name);
 }
 
-static void
-update_jobs_count (PpPrinterEntry *self)
+void
+pp_printer_entry_update_jobs_count (PpPrinterEntry *self)
 {
   cups_job_t *jobs = NULL;
   gchar *button_label;
   gint   num_jobs, num_of_jobs;
 
-  num_of_jobs = cupsGetJobs (&jobs, self->printer_name, 0, CUPS_WHICHJOBS_ACTIVE);
+  num_of_jobs = cupsGetJobs (&jobs, self->printer_name, 1, CUPS_WHICHJOBS_ACTIVE);
   num_jobs = num_of_jobs < 0 ? 0 : (guint) num_of_jobs;
 
   if (num_of_jobs <= 0)
@@ -376,6 +414,11 @@ update_jobs_count (PpPrinterEntry *self)
   gtk_button_set_label (GTK_BUTTON (self->show_jobs_dialog_button), button_label);
   gtk_widget_set_sensitive (self->show_jobs_dialog_button, num_jobs > 0);
 
+  if (self->pp_jobs_dialog != NULL)
+    {
+      pp_jobs_dialog_update (self->pp_jobs_dialog);
+    }
+
   g_free (button_label);
 }
 
@@ -388,7 +431,7 @@ jobs_dialog_response_cb (GtkDialog  *dialog,
 
   if (self->pp_jobs_dialog != NULL)
     {
-      /*pp_jobs_dialog_free (self->pp_jobs_dialog);*/
+      pp_jobs_dialog_free (self->pp_jobs_dialog);
       self->pp_jobs_dialog = NULL;
     }
 }
@@ -669,7 +712,7 @@ pp_printer_entry_new (cups_dest_t  printer,
 
   g_signal_connect (self->supply_drawing_area, "draw", G_CALLBACK (supply_levels_draw_cb), inklevel);
 
-  update_jobs_count (self);
+  pp_printer_entry_update_jobs_count (self);
 
   gtk_widget_set_sensitive (GTK_WIDGET (self->printer_default_checkbutton), self->is_authorized);
   gtk_widget_set_sensitive (GTK_WIDGET (self->remove_printer_menuitem), self->is_authorized);
